m4us.core.postoffices — Message For You Sir! v0.1.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Message For You Sir! v0.1.1 documentation »
- API Documentation »

# `m4us.core.postoffices`

Provides various kinds of post office classes for message routing.

Post offices are responsible for receiving posted messages from coroutines and routing them to message queues of other coroutines based on the links that have been registered.

## Inheritance Diagram

## Members

class `PostOffice`(link_ignores_duplicates=False, unlink_ignores_missing=False)

  Bases: `object`

  The standard post office class used for message routing.

  This is a simple and reasonably efficient implementation of `IPostOffice`. Unless you have a special need, this is this post office you want to use.

  Implements : | `IPostOffice`
  Provides : | `IPostOfficeFactory`

  `link`(first_link, *other_links)

    Register links between coroutines.

    See also

    The `IPostOffice` interface for details about this method.

  `post`(source, outbox, message)

    Post a message from the source outbox.

    See also

    The `IPostOffice` interface for details about this method.

  `retrieve`(sink)

    Retrieve all outstanding messages for a sink coroutine.

    See also

    The `IPostOffice` interface for details about this method.

  `unlink`(first_link, *other_links)

    Unregister previously registered links.

    See also

    The `IPostOffice` interface for details about this method.

### Navigation

- index
- modules |
- next |
- previous |
- Message For You Sir! v0.1.1 documentation »
- API Documentation »